@@ -15,22 +15,22 @@ _T = TypeVar("_T", bound=AlphaConfigSchema)
 
 def create_config_settings(
     model: Type[_T],
-    node_env_alias: str = "NODE_ENV",
-    config_dir_alias: str = "CONFIG_DIR",
+    environment_alias: str = "ALPHA_ENV",
+    config_dir_alias: str = "ALPHA_CONFIG_DIR",
 ):
     class AlphaConfigSettingsSchema(BaseSettings):
-        node_env: str = Field(validation_alias=node_env_alias)
+        environment: str = Field(validation_alias=environment_alias)
         config_dir: str = Field(validation_alias=config_dir_alias)
 
         @computed_field
         @property
         def main_config(self) -> _T:
-            config_file_path = Path(self.config_dir) / f"config.{self.node_env}.json"
+            config_file_path = Path(self.config_dir) / f"config.{self.environment}.json"
 
             data = open_json_file(path=config_file_path)
 
             data_ext = {
-                "node_env": self.node_env,
+                "environment": self.environment,
                 "config_file_path": config_file_path,
             }
 
